@@ -27,11 +27,11 @@ VEL_UNITS: str = POS_UNITS  # default is displacement in pix
 DELTA_T: np.float64 = 0.0  # default is 0. i.e. uknown, can be any float value
 
 
-def sorted_unique(arr: ArrayLike) -> ArrayLike:
+def unsorted_unique(arr: ArrayLike) -> ArrayLike:
     """creates a sorted unique numpy array"""
-    arr1, c = np.unique(arr, return_counts=True)
-    out = arr1[np.argsort(-c)]
-    return out
+    arr1, c = np.unique(arr, return_index=True)
+    out = arr1[c.argsort()]
+    return out, c
 
 
 def set_default_attrs(dataset: xr.Dataset) -> xr.Dataset:
@@ -212,14 +212,18 @@ def from_df(
     """
     d = df.to_numpy()
 
-    x = sorted_unique(d[:, 0])
-    y = sorted_unique(d[:, 1])
-    if d.shape[1] < 5:  # not always there's a mask
-        tmp = np.ones((d.shape[0], 5))
-        tmp[:, :-1] = d
-        d = tmp
-
-    d = d.reshape(len(y), len(x), 5)  # .transpose(1, 0, 2)
+    x, ix = unsorted_unique(d[:, 0])
+    y, iy = unsorted_unique(d[:, 1])
+    
+    if d.shape[1] < 5: # davis8 does not have mask or chc
+        d = np.column_stack((d,np.zeros_like(d[:,-1])))
+        
+    if ix[1] == 1: #x grows first
+        d = d.reshape(len(y), len(x), 5).transpose(1, 0, 2)
+    elif iy[1] == 1: # y grows first
+        d = d.reshape(len(x), len(y), 5) # .transpose(1,0,2)
+    else:
+        raise ValueError('not sorted x or y')
 
     u = d[:, :, 2]
     v = d[:, :, 3]
@@ -230,9 +234,9 @@ def from_df(
     v = v[:, :, np.newaxis]
     chc = chc[:, :, np.newaxis]
 
-    u = xr.DataArray(u, dims=("y", "x", "t"), coords={"x": x, "y": y, "t": [frame]})
-    v = xr.DataArray(v, dims=("y", "x", "t"), coords={"x": x, "y": y, "t": [frame]})
-    chc = xr.DataArray(chc, dims=("y", "x", "t"), coords={"x": x, "y": y, "t": [frame]})
+    u = xr.DataArray(u, dims=("x", "y", "t"), coords={"x": x, "y": y, "t": [frame]})
+    v = xr.DataArray(v, dims=("x", "y", "t"), coords={"x": x, "y": y, "t": [frame]})
+    chc = xr.DataArray(chc, dims=("x", "y", "t"), coords={"x": x, "y": y, "t": [frame]})
 
     dataset = xr.Dataset({"u": u, "v": v, "chc": chc})
     dataset = set_default_attrs(dataset)
@@ -265,21 +269,33 @@ def load_vec(
     """
     if rows is None or cols is None:
         _, _, rows, cols, dt, frame, _ = parse_header(filename)
+        # print(f'rows = {rows}, cols = {cols}')
 
-    if rows is None:  # means no headers
-        d = np.genfromtxt(filename, usecols=(0, 1, 2, 3, 4))
-        x = sorted_unique(d[:, 0])
-        y = sorted_unique(d[:, 1])
-        d = d.reshape(len(y), len(x), 5)  # .transpose(1, 0, 2)
-    else:
-        # d = np.genfromtxt(
-        #     filename, skiprows=1, delimiter=",", usecols=(0, 1, 2, 3, 4)
-        # ).reshape(rows, cols, 5)
+    if rows is None:  # means no headers, openpiv vec file
+        # d = np.genfromtxt(filename, usecols=(0, 1, 2, 3, 4))
+        d = np.genfromtxt(
+            filename, 
+            usecols=(0, 1, 2, 3, 4)
+          )
+        x, ix = unsorted_unique(d[:, 0])
+        y, iy = unsorted_unique(d[:, 1])
+        
+        # print(f'rows = {len(y)}, cols = {len(x)}')
+        
+        if ix[1] == 1: #x grows first
+            d = d.reshape(len(y), len(x), 5).transpose(1, 0, 2)
+        elif iy[1] == 1: # y grows first
+            d = d.reshape(len(y), len(x), 5) # .transpose(1,0,2)
+        else:
+            raise ValueError('not sorted x or y')
+    else: # Insight VEC file
         d = np.genfromtxt(
             filename, skip_header=1, delimiter=",", usecols=(0, 1, 2, 3, 4)
-        ).reshape(cols, rows, 5)
-        x = d[:, :, 0][0, :]
-        y = d[:, :, 1][:, 0]
+        ).reshape(cols, rows, 5).transpose(1, 0, 2)
+        
+        x = d[:, :, 0][:, 0]
+        y = d[:, :, 1][0, :]
+ 
 
     u = d[:, :, 2]
     v = d[:, :, 3]
@@ -290,9 +306,9 @@ def load_vec(
     v = v[:, :, np.newaxis]
     chc = chc[:, :, np.newaxis]
 
-    u = xr.DataArray(u, dims=("y", "x", "t"), coords={"x": x, "y": y, "t": [frame]})
-    v = xr.DataArray(v, dims=("y", "x", "t"), coords={"x": x, "y": y, "t": [frame]})
-    chc = xr.DataArray(chc, dims=("y", "x", "t"), coords={"x": x, "y": y, "t": [frame]})
+    u = xr.DataArray(u, dims=("x", "y", "t"), coords={"x": x, "y": y, "t": [frame]})
+    v = xr.DataArray(v, dims=("x", "y", "t"), coords={"x": x, "y": y, "t": [frame]})
+    chc = xr.DataArray(chc, dims=("x", "y", "t"), coords={"x": x, "y": y, "t": [frame]})
 
     dataset = xr.Dataset({"u": u, "v": v, "chc": chc})
 
@@ -304,6 +320,33 @@ def load_vec(
 
     return dataset
 
+def load_insight_vec_as_csv(
+    filename: pathlib.Path,
+    rows: int = None,
+    cols: int = None,
+    delta_t: float = None,
+    frame: int = 0,
+) -> xr.Dataset:
+    """
+    load_insight_vec_as_csv(filename,rows=rows,cols=cols)
+    Loads the VEC file (TECPLOT format by TSI Inc.),
+    Arguments:
+        filename : file name, expected to have a header and 5 columns
+        rows, cols : number of rows and columns of a vector field,
+        if None, None, then parse_header is called to infer the number
+        written in the header
+        DELTA_T : time interval (default is None)
+        frame : frame or time marker (default is None)
+    Output:
+        dataset is a xAarray Dataset, see xarray for help
+    """    
+    df = pd.read_csv(filename,header=None,skiprows=1,names=["x","y","u","v","chc"])
+    dataset = from_df(df,frame=frame,filename=filename)
+    
+    return dataset
+    
+    
+
 
 def load_vc7(
     filename: pathlib.Path,
@@ -537,9 +580,15 @@ def load_openpiv_txt(
     """
     if rows is None:  # means no headers
         d = np.genfromtxt(filename, usecols=(0, 1, 2, 3, 4))
-        x = sorted_unique(d[:, 0])
-        y = sorted_unique(d[:, 1])
-        d = d.reshape((len(y), len(x), 5)).transpose(1, 0, 2)
+        x, ix = unsorted_unique(d[:, 0])
+        y, iy = unsorted_unique(d[:, 1])
+
+        if ix[1] == 1: #x grows first
+            d = d.reshape(len(y), len(x), 5).transpose(1, 0, 2)
+        elif iy[1] == 1: # y grows first
+            d = d.reshape(len(y), len(x), 5)
+        else:
+            raise ValueError('not sorted x or y')
     else:
         d = np.genfromtxt(
             filename, skip_header=1, delimiter=",", usecols=(0, 1, 2, 3, 4)
@@ -581,6 +630,45 @@ def load_openpiv_txt(
     return dataset
 
 
+def load_openpiv_txt_as_csv(
+    filename: str,
+    rows: int = None,
+    cols: int = None,
+    delta_t: float = None,
+    frame: int = 0,
+) -> xr.Dataset:
+    """ loads OpenPIV txt file 
+
+    Args:
+        filename (str): _description_
+        rows (int, optional): _description_. Defaults to None.
+        cols (int, optional): _description_. Defaults to None.
+        delta_t (float, optional): _description_. Defaults to None.
+        frame (int, optional): _description_. Defaults to 0.
+
+    Returns:
+        xr.Dataset: _description_
+    """
+    df = pd.read_csv(
+        filename, 
+        header=None,
+        names=['x','y','u','v','chc'],
+        delim_whitespace=True
+    )
+    
+    dataset = from_df(
+        df,
+        frame=frame,
+        filename=filename
+    )
+    
+    return dataset
+    
+    
+    
+
+
+
 def load_davis8_txt(
     filename: pathlib.Path,
     rows: int = None, # pylint: disable=W0613
@@ -603,7 +691,7 @@ def load_davis8_txt(
     dataframe = pd.read_csv(
         filename, delimiter="\t", skiprows=1, names=["x", "y", "u", "v"], decimal=","
     )
-    dataset = from_df(dataframe, frame=frame)
+    dataset = from_df(dataframe, frame=frame,filename=filename)
     # print(f'{rows},{cols},{delta_t}')
     return dataset
 
