@@ -4,7 +4,10 @@ Created on Sun Macc_y 24 22:02:49 2015
 
 @author: Ron, Alex
 """
-from typing import Literal
+try:
+    from typing_extensions import Literal
+except ImportError:
+    from typing import Literal
 import numpy as np
 import xarray as xr
 from scipy.ndimage import gaussian_filter
@@ -117,16 +120,23 @@ class PIVAccessor(object):
         )
         return self._obj
 
-    def filterf(self):
+    def filterf(self, sigma: float=[1.,1.,0],**kwargs):
         """Gaussian filtering of velocity"""
 
         self._obj["u"] = xr.DataArray(
-            gaussian_filter(self._obj["u"].values, [1, 1, 0]), dims=("x", "y", "t")
+            gaussian_filter(
+                self._obj["u"].values, sigma, **kwargs),
+                dims=("y", "x", "t"),
+                attrs = self._obj["u"].attrs,
         )
         self._obj["v"] = xr.DataArray(
-            gaussian_filter(self._obj["v"].values, [1, 1, 0]), dims=("x", "y", "t")
+            gaussian_filter(
+                self._obj["v"].values, sigma, **kwargs),
+                dims=("y", "x", "t"),
+                attrs = self._obj["v"].attrs,
         )
 
+
         return self._obj
 
     def fill_nans(self, method: Literal["linear", "nearest", "cubic"] = "nearest"):
